#
# spec file for package gnome-dvb-daemon
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-dvb-daemon
Version:        0.2.90
Release:        5.2
Summary:        Daemon to use DVB devices
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Other
URL:            http://live.gnome.org/DVBDaemon
Source0:        http://download.gnome.org/sources/gnome-dvb-daemon/0.2/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  intltool >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  python3-devel >= 3.2
BuildRequires:  totem-devel
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.25.1
BuildRequires:  pkgconfig(gee-0.8) >= 0.8.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.4.0
BuildRequires:  pkgconfig(gstreamer-mpegts-1.0) >= 1.4.0
BuildRequires:  pkgconfig(gstreamer-rtsp-1.0) >= 1.4.0
BuildRequires:  pkgconfig(gstreamer-rtsp-server-1.0) >= 1.4.0
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(pygobject-3.0) >= 3.2.1
BuildRequires:  pkgconfig(sqlite3)

%description
DVB Daemon is a daemon written in Vala to setup your DVB devices,
record and watch TV shows and browse EPG. It can be controlled directly
via its D-Bus interface or with UI applications that come with it.

%package -n python-gnome-dvb-daemon
Summary:        Daemon to use DVB devices -- Python Library
Group:          Productivity/Multimedia/Other
URL:            http://live.gnome.org/DVBDaemon
Requires:       %{name} = %{version}
# Note: we put the Recommends for the lang package here and not in the main
# package because that's where the translatable strings live. We could change
# the name of the lang package, but the .mo files are named gnome-dvb-daemon,
# so it's better this way.
# For tuning data
Recommends:     dvb
Provides:       python-gnomedvb = %{version}

%description -n python-gnome-dvb-daemon
DVB Daemon is a daemon written in Vala to setup your DVB devices,
record and watch TV shows and browse EPG. It can be controlled directly
via its D-Bus interface or with UI applications that come with it.

This package contains a a Python library to use the D-Bus interfaces
of DVB Daemon.

%package -n totem-plugin-gnome-dvb-daemon
Summary:        Daemon to use DVB devices -- Totem Plugin
Group:          Productivity/Multimedia/Other
URL:            http://live.gnome.org/DVBDaemon
Requires:       python-gnome-dvb-daemon = %{version}
Requires:       totem
Supplements:    packageand(%{name}:totem)

%description -n totem-plugin-gnome-dvb-daemon
DVB Daemon is a daemon written in Vala to setup your DVB devices,
record and watch TV shows and browse EPG. It can be controlled directly
via its D-Bus interface or with UI applications that come with it.

This package contains a Totem plugin to use your DVB devices.

%lang_package

%prep
%autosetup -p1

%build
%global optflags %{optflags} -Wno-error=incompatible-pointer-types
%configure \
        --enable-totem-plugin
        %{nil}
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file gnome-dvb-control
%suse_update_desktop_file gnome-dvb-setup
# Two different calls, since the files are not in the same package
%fdupes %{buildroot}%{python_sitelib}
%fdupes %{buildroot}%{_libdir}/totem/

%post -n python-gnome-dvb-daemon
%desktop_database_post
%icon_theme_cache_post

%postun -n python-gnome-dvb-daemon
%desktop_database_postun
%icon_theme_cache_postun

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/gnome-dvb-daemon
%{_datadir}/dbus-1/services/org.gnome.DVB.service
%{_datadir}/dbus-1/services/org.gnome.UPnP.MediaServer2.DVBDaemon.service

%files -n python-gnome-dvb-daemon
%{_bindir}/gnome-dvb-control
%{_bindir}/gnome-dvb-setup
%{_datadir}/applications/gnome-dvb-control.desktop
%{_datadir}/applications/gnome-dvb-setup.desktop
%{_datadir}/icons/hicolor/*/apps/gnome-dvb-daemon.*
%{_datadir}/icons/hicolor/*/apps/gnome-dvb-setup.*
%{python3_sitelib}/gnomedvb/

%files -n totem-plugin-gnome-dvb-daemon
%{_libdir}/totem/plugins/dvb-daemon/

%files lang -f %{name}.lang

%changelog
* Fri Jul 12 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Add -Wno-error=incompatible-pointer-types to optflgas in order to
  prevent GCC 14 from reporting errors because of these C99
  violations
- Use modern macros.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Aug  8 2014 dimstar@opensuse.org
- Update to version 0.2.90:
  + Update daemon to use gstreamer 1.4.0.
  + Update client UI to python3.
  + Updated translations.
- Updated BuildRequires to match new dependencies:
  + Removed: python-devel, gstreamer-0_10-plugins-bad,
    gstreamer-0_10-plugins-good, gstreamer-0_10-utils,
    pkgconfig(gee-1.0), pkgconfig(gst-rtsp-server-0.10),
    pkgconfig(gstreamer-0.10), pkgconfig(gstreamer-rtsp-0.10).
  + Added: python3-devel, pkgconfig(gee-0.8),
    pkgconfig(gstreamer-1.0), pkgconfig(gstreamer-rtsp-1.0),
    pkgconfig(gstreamer-mpegts-1.0),
    pkgconfig(gstreamer-rtsp-server-1.0).
- Drop obsolete Requires: gstreamer-0_10-plugins-{good,bad}.
- Drop obsolete Requires from python-gnome-dvb-daemon:
  python-gobject2, python-gstreamer-0_10.
- Remove conditions to build on old openSUSE Variants: they do not
  ship GStreamer 1.4 anyway.
* Thu Feb 28 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Wed Oct 10 2012 dimstar@opensuse.org
- Update to version 0.2.10:
  + Updated list of countries for initial tuning data
  + Reuse thread in EPGScanner
  + Drop obsolete option from DBus files
  + Updated translations.
* Sun May 20 2012 dimstar@opensuse.org
- Update to version 0.2.9:
  + Remove overlapping events from EPGStore
  + Do not stop EPGScanner after failure
  + Print all log messages using Logger
  + Update timer in SQlite database when changing start time or
    duration
  + Updated translations.
* Tue Mar 20 2012 zaitor@opensuse.org
- Update to version 0.2.8:
  + Fix issues with Unicode encoding.
  + Remove a couple of deprecation warnings by Vala.
  + Updated translations.
- Remove xz BuildRequires since it comes for free in the
  buildsystem now.
* Tue Dec 13 2011 dimstar@opensuse.org
- Update to version 0.2.7:
  + gnomedvb: Let get_adapter_info return a dict
- Changes from version 0.2.6:
  + Don't use deprecated GTK+ widgets anymore
  + Use ugettext to make sure we always obtain an utf8 encoded
    string
  + totem-plugin: Change title of window to the name of the channel
    that is currently playing
  + gnomedvb: Remove userdirs module and use GLib via introspection
    instead
  + Added GetAdapterInfo method to Manager DBus interface
  + Droped python-gstreamer dependency
- Remove python-gstreamer-0_10 BuildRequires, following upstream
  change.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that...
  See bnc#697467 for more details.
* Mon Oct 10 2011 zaitor@opensuse.org
- Update to version 0.2.5:
  + This release updates the list of supported countries for DVB-C
    and DVB-T.
  - DVB-C: Czech Republic, Denmark, France, Hungary, Luxemburg,
    Spain.
  - DVB-T: Andorra, Azerbaijan, Croatia, Hungary, Iran, Israel,
    Latvia, Lithuania, Romania, Slovenia, Vietnam.
  + Append recordings to TreeStore with a single function call.
* Sun Oct  9 2011 zaitor@opensuse.org
- Update to version 0.2.4:
  + Fixed various issues with vala 0.14.0
  + When searching for recordings, skip hidden directories and set
    maximum recursion depth to three.
  + Updated translations.
* Thu Oct  6 2011 vuntz@opensuse.org
- Change vala-devel BuildRequires to vala as vala-devel is an old
  deprecated name (bnc#720908).
* Sun Sep 11 2011 vuntz@opensuse.org
- Update to version 0.2.3:
  + Fixed bug where extended event description was not displayed
    when selecting an event in SchedulePaned
  + Use GObject instead of gobject module
  + Fixed retrieving iter pointing to start of previous day in
    ScheduleStore
  + Don't bind gettext domain globally to avoid interfering with
    applications that import gnomedvb
  + Allow to add fake devices to settings.ini
  + Raised pygobject minimum version to 2.90.1
  + Changed order of columns in RecordingsView
  + Updated translations.
- Change pkgconfig(pygobject-2.0) BuildRequires to
  pkgconfig(pygobject-3.0), following upstream change.
* Tue Jun 21 2011 dimstar@opensuse.org
- Update to version 0.2.2:
  + Make sure that Channel's GroupId is set in the constructor
  + Removed shebang from DBusWrapper.py
  + Removed MediaServer1 D-Bus service file
  + Updated translations.
* Sat May 28 2011 dimstar@opensuse.org
- Update to version 0.2.1:
  + Fixed binding gettext domain
  + gnomedvb:
  - Set window position of preferences window
  - Launch gnome-dvb-setup when pressing on preferences button
  + Manager: disconnect from destroyed signal before destroying
    Scanners in shutdown
  + Adjusted DVB-T brute-force scan to new signature of
    AddScanningData method
  + Updated translations.
* Wed May 11 2011 dimstar@opensuse.org
- Update to version 0.2.0:
  + Fixed a couple of issues revealed by pylint
  + Totem: Fixed spawning of gnome-dvb-setup
  + Use void* instead of bool as return value in GThread function
  + Use async methods instead of calling the methods with Idle.add
  + Updated translations.
- Drop gnome-dvb-daemon-buildfix.patch: fixed upstream.
* Wed May  4 2011 dimstar@opensuse.org
- Update to version 0.1.90:
  + Ported GUI to PyGI and GTK+3
  + Use appointment-soon icon instead of stock_timer
  + Do not use Gtk.Alignment anymore
  + Mark what's on buttons insensitive if no device has been setup
  + Retrieve totem plugin dir from pkg-config variable
  + Avoid NULL pointer dereference in get_adapters()
  + Totem: Ported plugin to PyGI, GTK+3 and libpeas
  + Totem: Display recordings when changing 'group by' type.
  + Fixed --{enable,disable}-totem-plugin option
  + Ported the daemon to use gdbus instead of libdbus.
  + Removed support for Rygel's MediaServer1 interface.
  + Don't use deprecated functions anymore.
  + Use a single Scanner DBus interface for all adapter types
  + Ported GUI to use GDBus.
  + Totem: Ported plugin to GDBus
  + Use new logging facility.
- Replace totem BuildRequires with totem-devel (needed to find the
  plugindir variable from the .pc file).
- Replace python-gobject2 BuildRequires with
  pkgconfig(pygobject-2.0).
- Remove dbus-1-python, python-gtk, pkgconfig(dbus-1) and
  pkgconfig(dbus-1-glib) BuildRequires.
- Remove python-gtk Requires from python-gnome-dvb-daemon.
- Rebase gnome-dvb-daemon-buildfix.patch.
* Sun Mar 20 2011 dimstar@opensuse.org
- Update to version 0.1.23:
  + Make ScheduleView searchable by using the title
  + SchedulePaned: Don't allow to edit TextView
  + lp#680519: Totem: use dgettext to avoid overriding Totem's
    translations
  + lp#676263: Fixed compiler errors. Requires Vala >= 0.11.2
  + lp#683950: gnomedvb: Display adapter and frontend for each
    device in the setup assistant
  + Detect overlapping EPG events and remove outdated events.
  + Moved handling of GSequence to new class EventStorage.
  + Removed desktop_DATA from EXTRA_DIST
  + Use upstream gettext instead of glib one
  + Do not use hostname in rtsp streaming URL but use the IPv4
    address of the interface specified in the settings file.
- Add gnome-dvb-daemon-buildfix.patch: create worker threads as
  void* instead of bool. Fixes brp checks.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call missing relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
* Wed Dec 15 2010 vuntz@opensuse.org
- Add totem BuildRequires (which is already a Requires), for
  ownership of the plugin directories.
* Wed Oct 13 2010 vuntz@opensuse.org
- Update to version 0.1.22:
  + Schedule: Lock access when adding epg events to database
    (lp#642388)
  + gnomedvb: Insert channels into correct group when using more
    than one device group
  + rtsp: set address of RTSPServer
  + Fixed compiler warnings
  + Updated translations.
* Fri Sep  3 2010 vuntz@opensuse.org
- Initial package (version 0.1.21).
